Documentation
¶
Overview ¶
Package ociclient provides an implementation of oci.Interface that uses HTTP to talk to the remote registry.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Options ¶
type Options struct {
// DebugID is used to prefix any log messages printed by the client.
DebugID string
// Transport is used to make HTTP requests. The context passed
// to its RoundTrip method will have an appropriate
// [ociauth.RequestInfo] value added, suitable for consumption
// by the transport created by [ociauth.NewStdTransport]. If
// Transport is nil, [http.DefaultTransport] will be used.
Transport http.RoundTripper
// Insecure specifies whether an http scheme will be used to
// address the host instead of https.
Insecure bool
// Specifies a user agent string to use when making requests. Defaults to "docker/oci"
UserAgent string
}
Options holds configuration for creating a new OCI registry client.
Click to show internal directories.
Click to hide internal directories.