ocidebug

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Overview

Package ocidebug is an OCI registry wrapper that prints log messages on registry operations.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(r oci.Interface, logf func(f string, a ...any)) oci.Interface

New returns a new oci.Interface that wraps r and logs all operations using the given logf function. If logf is nil, log.Printf is used.

Types

This section is empty.

Jump to